'use client'

import { Box, Button, Fade, Flex, Text } from '@chakra-ui/react';
import { useRouter } from 'next/navigation';
import React, { useState } from 'react'
import Image from 'next/image';

interface CardListProps {
    full_name: string;
    contact_information: string;
    address: string;
    meter_no: string;
    property_type: string;
}

const CardList = ({ data = [] }: { data?: CardListProps[] }) => {
    const router = useRouter();
    const [openCardIndex, setOpenCardIndex] = useState(null);

    const toggleCard = (index: number) => {
        setOpenCardIndex(openCardIndex === index ? null : index);
    };

    return (
        <>
            <Button
                onClick={() => router.push("/officer/attempted/create")}
            >
                Create
            </Button>

            {data?.map((consumer: CardListProps, index: number) => (
                <Box key={index} border='1px' p={3} rounded={20} mt={'70px'}>
                    <Flex gap={2} alignItems="center">
                        <Box w='40px'>
                            <Image src='https://bit.ly/dan-abramov' alt='Dan Abramov' width={40} height={40} />
                        </Box>
                        <Flex flexDirection={'row'} gap={10} onClick={() => toggleCard(index)}>
                            <Text fontSize="lg" fontWeight={"bold"} sx={{ textTransform: 'uppercase' }}>
                                {consumer?.full_name}
                            </Text>

                        </Flex>
                    </Flex>

                    {openCardIndex === index && (
                        <Fade in={openCardIndex === index} animateOpacity >
                            <Box
                                py='1'
                                mt={3}
                                px={0}
                                color='white'
                                rounded='md'
                                shadow='md'
                            >
                                <Flex rowGap={1} alignItems="center" flexWrap="wrap" justifyContent="space-between">
                                    <Box width={'50%'}>
                                        <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: 'capitalized' }}>
                                            Contact Info: &nbsp;
                                            <Text as='span' fontWeight="normal">
                                                {consumer?.contact_information}
                                            </Text>
                                        </Text>
                                    </Box>
                                    <Box width={'50%'}>
                                        <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: 'capitalized' }}>
                                            Address: &nbsp;
                                            <Text as='span' fontWeight="normal">
                                                {consumer?.address}
                                            </Text>
                                        </Text>
                                    </Box>
                                    <Box width={'50%'}>
                                        <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: 'capitalized' }}>
                                            Meter No: &nbsp;
                                            <Text as='span' fontWeight="normal">
                                                {consumer?.meter_no}
                                            </Text>
                                        </Text>
                                    </Box>
                                    <Box width={'50%'}>
                                        <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: 'capitalized' }}>
                                            Property Type: &nbsp;
                                            <Text as='span' fontWeight="normal">
                                                {consumer?.property_type}
                                            </Text>
                                        </Text>
                                    </Box>
                                </Flex>
                            </Box>
                        </Fade>
                    )}
                    <Flex columnGap={1} alignItems="center" mt="6">
                        <Button
                            onClick={() => router.push("/officer/attempted/create")}
                            size="sm" px="3"
                        >
                            Attempted
                        </Button>
                        <Button size="sm" px="3">
                            Re Attempted
                        </Button>
                        <Button size="sm" px="3">
                            Reset
                        </Button>
                    </Flex>
                </Box>
            ))}
        </>
    )
}

export default CardList